# Build and install the Java version of Python
# By Scott Pakin <pakin@uiuc.edu>

Name:        jpython
Version:     1.1
Release:     1
Summary:     Python interpreter+compiler written in Java
Copyright:   Hybrid BSD-ish + non-open source
Vendor:      Scott Pakin <pakin@uiuc.edu>
URL:         http://www.jpython.org
Group:       Development/Languages
BuildRoot:   /var/tmp/%{name}-%{version}
Prefix:      /usr
Source0:     http://www.jpython.org/JPython11.class
Source1:     http://download.sourceforge.net/bckfnn-modules/errata-07.tar.gz
BuildPrereq: python, gawk
BuildArchitectures: noarch
Prereq:      python

%define jpython_top %{_builddir}/%{name}-%{version}
%define jpython_sharedir %{prefix}/share/JPython-%{version}

%description
JPython is an implementation of the high-level, dynamic, object-oriented
language Python written in 100% Pure Java (certified), and seamlessly
integrated with the Java platform.  It thus allows you to run Python on any
Java platform.

NOTE: %{name}-%{version}-%{release}.src.rpm doesn't actually contain the JPython source
code, but rather the OROMatcher classball and Finn Bock's JPython patches.

%prep
rm -rf %{name}-%{version}
jre -cp %{_sourcedir} JPython11 -o %{jpython_top}
if [ $? -ne 0 ]; then
  exit $?
fi
%setup -D -T -a 1

%build
# Build all the Python library files into .class files now, because an
# ordinary user won't have sufficient access to write the .class files into
# the Lib directory.
cd Lib
%{jpython_top}/jpythonc *.py
cd pawt
%{jpython_top}/jpythonc *.py
cd %{_builddir}/%{name}-%{version}
rm -rf `find Lib -name jpywork`
find Lib -name "*.class" -exec chmod 0644 {} \;
# Create a brief README file.
cat <<EOF > README.RPM
		       Some notes on the JPython RPM
		      by Scott Pakin <pakin@uiuc.edu>
		      -------------------------------

1) %{name}-%{version}-%{release}.src.rpm doesn't actually contain the JPython source
   code, but rather the OROMatcher classball and Finn Bock's JPython
   patches.  See http://www.jpython.org/newlicense.html for information on
   the OROMatcher versus non-OROMatcher versions, and see
   http://sourceforge.net/project/?group_id=1842 for Finn Bock's JPython
   modules.

2) JPython depends on Java, but %{name}-%{version}-%{release}.%{_arch}.rpm doesn't
   list Java as a dependency.  The problem is that every Java package
   provides something different, at least by name.  Should JPython depend
   on "java", "jdk", "jre", or "guavac"?  Should it require /usr/bin/javac,
   /usr/local/jdk117_v3/bin/javac, /usr/jdk1.2/bin/javac, or something
   else?  What if you want to use Jikes as your Java compiler and Kaffe as
   your JVM?  I decided to punt on this one and not have the JPython RPM
   depend on Java, even though JPython obviously requires it.

3) Don't forget to set your CLASSPATH environment variable appropriately
   for your compiler and virtual machine.  If Java doesn't run, JPython
   won't, either.

4) I hacked up the jpython script so that the first time you run jpython or
   jpythonc, the script will create a ~/.jpython configuration file and a
   ~/.jpcachedir directory for caching state.  This is better (and more
   secure) than having all users share a single cache directory.
EOF

%install
install -d -m 755 $RPM_BUILD_ROOT%{jpython_sharedir}
install -c -m 644 registry $RPM_BUILD_ROOT%{jpython_sharedir}/registry
install -c -m 644 jpython.jar $RPM_BUILD_ROOT%{jpython_sharedir}/
cp -r Lib $RPM_BUILD_ROOT%{jpython_sharedir}/
cp -r Tools $RPM_BUILD_ROOT%{jpython_sharedir}/
install -d -m 755 $RPM_BUILD_ROOT%{prefix}/bin/
find $RPM_BUILD_ROOT -name Makefile -exec rm {} \;
touch ${RPM_BUILD_ROOT}%{prefix}/bin/jpython
touch ${RPM_BUILD_ROOT}%{prefix}/bin/jpythonc

%post
# Create customized versions of the jpython and jpythonc scripts.
JPYTHON_SHAREDIR=${RPM_INSTALL_PREFIX}/share/JPython-%{version}
cat <<EOF > ${RPM_INSTALL_PREFIX}/bin/jpython
#! /bin/sh
# This file generated by the JPython RPM
# Created on `date` by pakin
if [ ! -e ~/.jpython ]; then
  CACHEDIR=\`echo ~/.jpcachedir\`
  PYPATH=\`python -c 'import sys ; import string ; print string.joinfields(sys.path,":")'\`
  cat ${JPYTHON_SHAREDIR}/registry | sed "s|= cachedir|= \$CACHEDIR|" | \\
    sed "s|^python.path = \\.|python.path = \$PYPATH|" > ~/.jpython
fi
exec java -Dpython.home=${JPYTHON_SHAREDIR} -classpath "${JPYTHON_SHAREDIR}/jpython.jar:\$CLASSPATH" org.python.util.jpython "\$@"
EOF
cat <<EOF > ${RPM_INSTALL_PREFIX}/bin/jpythonc
#! /bin/sh
# This file generated by the JPython RPM
# Created on `date` by pakin
${RPM_INSTALL_PREFIX}/bin/jpython ${JPYTHON_SHAREDIR}/Tools/jpythonc2/jpythonc.py "\$@"
EOF
chmod 755 ${RPM_INSTALL_PREFIX}/bin/jpython ${RPM_INSTALL_PREFIX}/bin/jpythonc

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-, root, root)
%doc ACKNOWLEDGMENTS LICENSE.txt NEWS demo docs html README.RPM
%dir %{jpython_sharedir}
%config %{jpython_sharedir}/registry
%{jpython_sharedir}/jpython.jar
%{jpython_sharedir}/Lib
%{jpython_sharedir}/Tools
%{prefix}/bin/jpython
%{prefix}/bin/jpythonc

%changelog
* Wed Aug 09 2000 Scott Pakin <pakin@uiuc.edu>
- Initial version
